==> apache-reef-0.14.0.tar.gz: apache-reef-0.14.0/lang/cs/Org.Apache.REEF.Client/YARN/IJobResourceUploader.cs <==
﻿// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
// 
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

using Org.Apache.REEF.Tang.Annotations;

namespace Org.Apache.REEF.Client.Yarn
{
    [DefaultImplementation(typeof(LegacyJobResourceUploader))]
    public interface IJobResourceUploader
    {
        /// <summary>
        /// Creates the archive from local driver folder and uploads it to DFS destination path.
        /// </summary>
        /// <param name="driverLocalFolderPath">Local folder where REEF application resources are staged</param>
        /// <param name="remoteUploadDirectoryPath">Remote directory path where we will upload resources</param>
        /// <returns>Path, modification time and size of uploaded file as JobResource</returns>
        JobResource UploadArchiveResource(string driverLocalFolderPath, string remoteUploadDirectoryPath);

        /// <summary>
        /// Locates a file resource and uploads it to DFS destination path.
        /// </summary>
        /// <param name="fileLocalPath">file path</param>
        /// <param name="remoteUploadDirectoryPath">Remote directory path where we will upload resources</param>
        /// <returns>Path, modification time and size of uploaded file as JobResource</returns>
        JobResource UploadFileResource(string fileLocalPath, string remoteUploadDirectoryPath);
    }
}

==> apache-reef-0.16.1.tar.gz: apache-reef-0.16.1/lang/cs/Org.Apache.REEF.Client/YARN/IJobResourceUploader.cs <==
﻿// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
// 
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

using System.Threading.Tasks;
using Org.Apache.REEF.Tang.Annotations;

namespace Org.Apache.REEF.Client.Yarn
{
    [DefaultImplementation(typeof(LegacyJobResourceUploader))]
    public interface IJobResourceUploader
    {
        /// <summary>
        /// Creates the archive from local driver folder and uploads it to DFS destination path.
        /// </summary>
        /// <param name="driverLocalFolderPath">Local folder where REEF application resources are staged</param>
        /// <param name="remoteUploadDirectoryPath">Remote directory path where we will upload resources</param>
        /// <returns>Path, modification time and size of uploaded file as JobResource</returns>
        Task<JobResource> UploadArchiveResourceAsync(string driverLocalFolderPath, string remoteUploadDirectoryPath);

        /// <summary>
        /// Locates a file resource and uploads it to DFS destination path.
        /// </summary>
        /// <param name="fileLocalPath">file path</param>
        /// <param name="remoteUploadDirectoryPath">Remote directory path where we will upload resources</param>
        /// <returns>Path, modification time and size of uploaded file as JobResource</returns>
        Task<JobResource> UploadFileResourceAsync(string fileLocalPath, string remoteUploadDirectoryPath);
    }
}
